@@ -1,7 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
-from payment_term import *
-from invoice import *
-from party import *
-from account import *
+from .payment_term import *
+from .invoice import *
+from .party import *
+from .account import *
